# Summary

- [Introduction](./introduction.md)

- [Quickstart](./quickstart/intro.md)
  - [Map Parsing and Modification](./quickstart/map_modification.md)
  - [Icon Parsing and Extraction](./quickstart/icon_parsing.md)
  - [Environment Parsing](./quickstart/environment_parsing.md)
  - [Putting It All Together](./quickstart/putting_it_all_together.md)
  - [Conclusion](./quickstart/conclusion.md)

- [Reference](./reference/intro.md)
  - [Paths](./reference/paths.md)
  - [DMM and Tiledefs](./reference/dmm_and_tiledefs.md)
  - [DMI](./reference/dmi.md)
  - [DME](./reference/dme.md)
